==> jc-1.4.0.tar.gz: javax/swing/SpinnerNumberModel__242.h <==
// final class javax.swing.SpinnerNumberModel$2

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1ff6d3b55aef3e8b javax_swing_SpinnerNumberModel__242

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_SpinnerNumberModel__242_H_
#define _JC_javax_swing_SpinnerNumberModel__242_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_javax_swing_SpinnerNumberModel$object;

// Typedefs
typedef struct _jc_javax_swing_SpinnerNumberModel__242$sub_refs	_jc_javax_swing_SpinnerNumberModel__242$sub_refs;
typedef struct _jc_javax_swing_SpinnerNumberModel__242$sub_nonrefs	_jc_javax_swing_SpinnerNumberModel__242$sub_nonrefs;
typedef struct _jc_javax_swing_SpinnerNumberModel__242$refs	_jc_javax_swing_SpinnerNumberModel__242$refs;
typedef struct _jc_javax_swing_SpinnerNumberModel__242$nonrefs	_jc_javax_swing_SpinnerNumberModel__242$nonrefs;
typedef struct _jc_javax_swing_SpinnerNumberModel__242$object	_jc_javax_swing_SpinnerNumberModel__242$object;

typedef const struct _jc_javax_swing_SpinnerNumberModel__242$vmethods	_jc_javax_swing_SpinnerNumberModel__242$vmethods;
typedef const struct _jc_javax_swing_SpinnerNumberModel__242$vtable	_jc_javax_swing_SpinnerNumberModel__242$vtable;
typedef const struct _jc_javax_swing_SpinnerNumberModel__242$vtype	_jc_javax_swing_SpinnerNumberModel__242$vtype;

// Constructors
extern void _jc_javax_swing_SpinnerNumberModel__242$method$_init$60f9faf403b24199(_jc_env *, struct _jc_javax_swing_SpinnerNumberModel__242$object *, struct _jc_javax_swing_SpinnerNumberModel$object *);

// Virtual methods
extern jint _jc_javax_swing_SpinnerNumberModel__242$method$compareTo$84fc6fc4a23c98a3(_jc_env *, struct _jc_javax_swing_SpinnerNumberModel__242$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_SpinnerNumberModel__242$method_info$compareTo$84fc6fc4a23c98a3;

// Virtual methods structure
struct _jc_javax_swing_SpinnerNumberModel__242$vmethods {
	jint	(*compareTo$84fc6fc4a23c98a3)(_jc_env *, struct _jc_javax_swing_SpinnerNumberModel__242$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_javax_swing_SpinnerNumberModel__242$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_SpinnerNumberModel__242$vmethods	javax_swing_SpinnerNumberModel__242;
};

// Vtype
struct _jc_javax_swing_SpinnerNumberModel__242$vtype {
	_jc_type			type;
	_jc_javax_swing_SpinnerNumberModel__242$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_SpinnerNumberModel__242$sub_refs {
	struct _jc_javax_swing_SpinnerNumberModel$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_SpinnerNumberModel__242$refs {
    _jc_javax_swing_SpinnerNumberModel__242$sub_refs	javax_swing_SpinnerNumberModel__242;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_SpinnerNumberModel__242$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_SpinnerNumberModel__242$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_SpinnerNumberModel__242$sub_nonrefs	javax_swing_SpinnerNumberModel__242;
};

// Object instance structure
struct _jc_javax_swing_SpinnerNumberModel__242$object {
	_jc_javax_swing_SpinnerNumberModel__242$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_SpinnerNumberModel__242$vtype	*vtype;
	_jc_javax_swing_SpinnerNumberModel__242$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_SpinnerNumberModel__242$vtype _jc_javax_swing_SpinnerNumberModel__242$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_SpinnerNumberModel__242, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_SpinnerNumberModel__242$class_object;

#endif	/* _JC_javax_swing_SpinnerNumberModel__242_H_ */

==> jc-1.4.6.tar.gz: javax/swing/SpinnerNumberModel__242.h <==
// final class javax.swing.SpinnerNumberModel$2

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 1ff6d3b55aef3e8b javax_swing_SpinnerNumberModel__242

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_SpinnerNumberModel__242_H_
#define _JC_javax_swing_SpinnerNumberModel__242_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_javax_swing_SpinnerNumberModel$object;

// Typedefs
typedef struct _jc_javax_swing_SpinnerNumberModel__242$sub_refs	_jc_javax_swing_SpinnerNumberModel__242$sub_refs;
typedef struct _jc_javax_swing_SpinnerNumberModel__242$sub_nonrefs	_jc_javax_swing_SpinnerNumberModel__242$sub_nonrefs;
typedef struct _jc_javax_swing_SpinnerNumberModel__242$refs	_jc_javax_swing_SpinnerNumberModel__242$refs;
typedef struct _jc_javax_swing_SpinnerNumberModel__242$nonrefs	_jc_javax_swing_SpinnerNumberModel__242$nonrefs;
typedef struct _jc_javax_swing_SpinnerNumberModel__242$object	_jc_javax_swing_SpinnerNumberModel__242$object;

typedef const struct _jc_javax_swing_SpinnerNumberModel__242$vmethods	_jc_javax_swing_SpinnerNumberModel__242$vmethods;
typedef const struct _jc_javax_swing_SpinnerNumberModel__242$vtable	_jc_javax_swing_SpinnerNumberModel__242$vtable;
typedef const struct _jc_javax_swing_SpinnerNumberModel__242$vtype	_jc_javax_swing_SpinnerNumberModel__242$vtype;

// Constructors
extern void _jc_javax_swing_SpinnerNumberModel__242$method$_init$60f9faf403b24199(_jc_env *, struct _jc_javax_swing_SpinnerNumberModel__242$object *, struct _jc_javax_swing_SpinnerNumberModel$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_javax_swing_SpinnerNumberModel__242$method$compareTo$84fc6fc4a23c98a3(_jc_env *, struct _jc_javax_swing_SpinnerNumberModel__242$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_SpinnerNumberModel__242$method_info$compareTo$84fc6fc4a23c98a3;

// Virtual methods structure
struct _jc_javax_swing_SpinnerNumberModel__242$vmethods {
	jint	(*compareTo$84fc6fc4a23c98a3)(_jc_env *, struct _jc_javax_swing_SpinnerNumberModel__242$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_SpinnerNumberModel__242$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_SpinnerNumberModel__242$vmethods	javax_swing_SpinnerNumberModel__242;
};

// Vtype
struct _jc_javax_swing_SpinnerNumberModel__242$vtype {
	_jc_type			type;
	_jc_javax_swing_SpinnerNumberModel__242$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_SpinnerNumberModel__242$sub_refs {
	struct _jc_javax_swing_SpinnerNumberModel$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_SpinnerNumberModel__242$refs {
    _jc_javax_swing_SpinnerNumberModel__242$sub_refs	javax_swing_SpinnerNumberModel__242;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_SpinnerNumberModel__242$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_SpinnerNumberModel__242$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_SpinnerNumberModel__242$sub_nonrefs	javax_swing_SpinnerNumberModel__242;
};

// Object instance structure
struct _jc_javax_swing_SpinnerNumberModel__242$object {
	_jc_javax_swing_SpinnerNumberModel__242$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_SpinnerNumberModel__242$vtype	*vtype;
	_jc_javax_swing_SpinnerNumberModel__242$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_SpinnerNumberModel__242$vtype _jc_javax_swing_SpinnerNumberModel__242$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_SpinnerNumberModel__242, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_SpinnerNumberModel__242$class_object;

#endif	/* _JC_javax_swing_SpinnerNumberModel__242_H_ */
